@@ -3,6 +3,7 @@ Base class for all Hoppr plug-ins
 """
 
 import functools
+from os import PathLike
 import subprocess
 import time
 import traceback
@@ -177,6 +178,7 @@ class HopprPlugin(ABC):
 
     default_component_coverage = ComponentCoverage.OPTIONAL
     bom_access = BomAccess.NO_ACCESS
+    process_timeout = 60
 
     def __init__(
         self,
@@ -188,6 +190,10 @@ class HopprPlugin(ABC):
         self.context = context
         self.config = config
 
+        if self.config is not None:
+            if "process_timeout" in self.config:
+                self.process_timeout = self.config["process_timeout"]
+
     @abstractmethod
     def get_version(self) -> str:
         """
@@ -251,14 +257,30 @@ class HopprPlugin(ABC):
         """
         self._logger.close()
 
-    def run_command(self, command, password_list=None, cwd=None) -> subprocess.CompletedProcess[bytes]:
+    def run_command(
+        self,
+        command: list[str],
+        password_list: Optional[list[str]] = None,
+        cwd: Optional[str | PathLike] = None,
+    ) -> subprocess.CompletedProcess[bytes]:
+
         """
         Run a command and log any errors
         """
         obscured_command = obscure_passwords(command, password_list)
         self.get_logger().debug(msg=f"Running command: '{obscured_command}'", indent_level=2)
 
-        result = subprocess.run(command, check=False, capture_output=True, cwd=cwd)
+        try:
+            result = subprocess.run(
+                command, check=False, shell=False, capture_output=True, cwd=cwd, timeout=self.process_timeout
+            )
+        except subprocess.TimeoutExpired as timeout_expired:
+            self.get_logger().error(
+                f"Command \"{command[0]}\" timed out after {timeout_expired.timeout} seconds", indent_level=2
+            )
+            result = subprocess.CompletedProcess(
+                command, returncode=124, stdout=timeout_expired.stdout or b'', stderr=timeout_expired.stderr or b''
+            )
 
         if result.returncode != 0:
             # Prefix each line of the command's stdout with 4 spaces
