@@ -4,6 +4,7 @@ Collector plugin for maven artifacts
 from __future__ import annotations
 
 from copy import deepcopy
+import os
 from pathlib import Path
 from subprocess import CalledProcessError
 from tempfile import NamedTemporaryFile
@@ -25,7 +26,7 @@ from hoppr.hoppr_types.manifest_file_content import Repository
 from hoppr.hoppr_types.purl_type import PurlType
 from hoppr.result import Result
 
-_MAVEN_DEP_PLUGIN = "org.apache.maven.plugins:maven-dependency-plugin:3.4.0"
+_MAVEN_DEP_PLUGIN = "org.apache.maven.plugins:maven-dependency-plugin:3.5.0"
 
 
 class CollectMavenPlugin(SerialCollectorPlugin):
@@ -80,7 +81,18 @@ class CollectMavenPlugin(SerialCollectorPlugin):
         for key, value in kwargs.items():
             full_command.append(f"-D{key}={value}")
 
-        return self.run_command(full_command, password_list)
+        result = self.run_command(full_command, password_list)
+
+        # The maven plugin does not recognize the 'destFileName' argument, so rename the file
+        if result.returncode == 0:
+            _, name, version, extension = kwargs.get("artifact", "::::").split(":")
+            directory = kwargs.get("outputDirectory", ".")
+            old_name = f"{name}-{version}.{extension}"
+            new_name = kwargs.get("destFileName", f"{name}_{version}.{extension}")
+
+            os.rename(directory / old_name, directory / new_name)
+
+        return result
 
     @hoppr_rerunner
     def collect(self, comp: Component, repo_url: str, creds: CredObject | None = None) -> Result:
@@ -125,7 +137,7 @@ class CollectMavenPlugin(SerialCollectorPlugin):
             defines = {
                 "artifact": f"{artifact}:{extension}",
                 "outputDirectory": target_dir,
-                "destFileName": f"{purl.name}-{purl.version}.{extension}",
+                "destFileName": f"{purl.name}_{purl.version}.{extension}",
                 "remoteRepositories": f"repoId::::{repo_url}",
             }
 
