@@ -6,6 +6,7 @@ import inspect
 import itertools
 import logging
 import os
+
 from logging.handlers import MemoryHandler
 from typing import Any, Optional
 
@@ -54,9 +55,7 @@ class MemoryLogger:
         file_handler = logging.FileHandler(file_name)
         file_handler.setFormatter(formatter)
 
-        log_handler = MemoryHandler(
-            10000, flushLevel=logging.CRITICAL, target=file_handler
-        )
+        log_handler = MemoryHandler(10000, flushLevel=logging.CRITICAL, target=file_handler)
 
         log_handler.setFormatter(formatter)
         self._logger.addHandler(log_handler)
